This module provides the low level communications functionality used by the [Life360 Device Tracker Platform for Home Assistant](https://github.com/pnbruckner/homeassistant-config/blob/master/docs/life360.md).

For releases prior to 2.0.0 see https://github.com/pnbruckner/homeassistant-config/blob/d01553da9066ac83c6a750099b3bdbe4eddf22a2/docs/life360_lib.md.
